;Dst_prediction.pro
;
;procedure for calculating possible |Dst| ranges and exact |Dst| level based on the 4-bin probability distribution for |Dst|.
;|Dst| ranges and exact |Dst| levels are determined using empirically obtained threshold parameters.
;
;The procedure needs two arrays as an input: p_c and thresholds:
;
;p_c
;1x4 array of input variables:
;column 1: probability for |Dst| < 100 nT
;column 2: probability for 100 nT < |Dst| < 200 nT
;column 3: probability for 200 nT < |Dst| < 300 nT
;column 4: probability for |Dst| > 300 nT
;If p_c is unknown, it should be put p_c=fltarr(4), the procedure then sends out a warning.
;
;thresholds.txt
;=3x2 array of threshold parameters:
;column 1: tresholds for 1st bin probability, Fr(k=1) (probability for k=1, i.e. |Dst| < 100 nT)
;column 2: tresholds for 3rd bin probability, Fr(k=3) (probability for k=3, i.e. 200 < |Dst| < 300 nT)
;column 3: tresholds for 4th bin probability, Fr(k=4) (probability for k=4, i.e. |Dst| > 300 nT)
;row 1: thresholds that determine whether |Dst| < 100 nT
;row 2: thresholds that determine whether |Dst| > 200 nT
;
;The output is a string representing expected |Dst| level
;
;*****************************************************************************************************************************************************************
;

PRO dst_prediction, p_c, thresholds, Dst_expected


Dst_expected=''
condition=make_array(3,1)
average=0.

;calculating |Dst| ranges
case 1 of
(p_c(0) GT thresholds(0,0)): condition(0)=1
else: condition(0)=0
endcase

case 1 of
(p_c(2) LT thresholds(1,0)): condition(1)=1
else: condition(1)=0
endcase

case 1 of
(p_c(3) LT thresholds(2,0)): condition(2)=1
else: condition(2)=0
endcase

average=(condition(0)+condition(1)+condition(2))/3
if (average GT 0.5) then (Dst_expected='1') else begin

  case 1 of
  (p_c(0) LT thresholds(0,1)): condition(0)=1
  else: condition(0)=0
  endcase

  case 1 of
  (p_c(2) GT thresholds(1,1)): condition(1)=1
  else: condition(1)=0
  endcase

  case 1 of
  (p_c(3) GT thresholds(2,1)): condition(2)=1
  else: condition(2)=0
  endcase
  
  average=(condition(0)+condition(1)+condition(2))/3
  if (average GT 0.5) then (Dst_expected='3') else (Dst_expected='2')
  
endelse

end